[![Build Status](https://travis-ci.com/hukkinj1/cosmospy.svg?branch=master)](https://travis-ci.com/hukkinj1/cosmospy)
[![codecov.io](https://codecov.io/gh/hukkinj1/cosmospy/branch/master/graph/badge.svg)](https://codecov.io/gh/hukkinj1/cosmospy)
[![LoC](https://tokei.rs/b1/github/hukkinj1/cosmospy)](https://tokei.rs/b1/github/hukkinj1/cosmospy)
# cosmospy

<!--- Don't edit the version line below manually. Let bump2version do it for you. -->
> Version 0.0.1

> Tools for Cosmos wallet management and offline transaction signing

## Requirements
```bash
apt-get install libsecp256k1-dev
```
